@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 
 """
-ver 2010 08 30 22
+ver 2010 08 31 09
 autor Bartlomiej Ceglik
 e-mail yoyoek[no spam]wp.pl
 """
@@ -82,9 +82,9 @@ import gtk.glade
 import glib
 import hildon
 import os
+import httplib
 
 
-import socket
 try:
     from icalendar import Calendar, Event
 except:
@@ -97,60 +97,28 @@ import time
 sql_file = '/home/user/.calendar/calendardb'
 sql_debug = 0
 error = 0
-
 done_ok = ''
 
 
 def Read_ical_from_web( host, file ):
-    tr = ''
 
     try:
-        s = socket.socket()
-        s.connect((host, 80))
+        conn = httplib.HTTPConnection( host )
     except:
         Info_no_connection()
         return ''
-    s.send("""GET """+file+""" HTTP/1.1
-Host: """+host+"""
 
+    conn.request("GET", file)
 
-""")
-
-    recive_tmp = ""
-    iter = 0
-    while iter<500:
-        d = s.recv(1024)
-        #print '[socket recv]'+d
-        if not d:
-            break
-        else:
-            recive_tmp = recive_tmp+d
-        if len(recive_tmp.split('END:VCALENDAR'))>1:
-            break
-        if len(recive_tmp.split("\n0\n\n"))>1 and iter > 0:
-            break
-
-        iter = iter + 1
-
-    split_res = recive_tmp.split('BEGIN:VCALENDAR')
-    if len(split_res) > 1:
-        tr = "BEGIN:VCALENDAR"+split_res[1]
-    else:
+    r1 = conn.getresponse()
+    if r1.reason <> 'OK':
+        print "connection error result\n-----------------------"
+        print r1.status
+        print "-----------------------"
         return ''
+    print 'feathing data from http ok :)'
+    return r1.read()
 
-    split_res = tr.split('END:VCALENDAR')
-    if len(split_res) > 1:
-        tr = split_res[0]+"END:VCALENDAR"
-    else:
-        return ''
-
-    tr = tr.replace("\r\n1000\r\n", '')
-    tr = tr.replace("\r\nb66\r\n", '')
-    tr = tr.replace("\r\n ", ' ')
-    tr = tr.replace("\n ", ' ')
-    tr = tr.replace("\r ",' ')
-
-    return tr
 
 
 def list_join( list, glut ):
@@ -215,9 +183,9 @@ def ParseStrTime_to_unix( str_time ):
         tr = time.mktime(time.strptime(str(str_time),'%Y%m%dT%H%M%SZ' ))
     except:
         try:
-            tr = time.mktime(time.strptime(str(str_time),'%Y%m%d' ))
-        except:
             tr = time.mktime(time.strptime(str(str_time),'%Y%m%dT%H%M%S' ))
+        except:
+            tr = time.mktime(time.strptime(str(str_time),'%Y%m%d' ))
     return tr
 
 def Call_featch_val( item, val_name ):
@@ -264,8 +232,14 @@ def Run_import():
                 print ical_str
                 print "---------------- EXITING --------------------------------------------\n"
                 break
+
             cal_name_item = cal.walk("VCALENDAR")
-            cal_name = cal_name_item[0]['X-WR-CALNAME']+" (webcal)"
+            try:
+                cal_name = cal_name_item[0]['X-WR-CALNAME']+" (webcal)"
+            except:
+                print "[Cal name not deff :/ set from X-WR-CALDESC]"
+                cal_name = cal_name_item[0]['X-WR-CALDESC']+" (webcal)"
+
             print "[Start ical iter]    [ical name] ["+cal_name+"]"
 
             print "[Start ical iter]    [sql try connect]"
